==> nmail-php-patch-2.5.2-to-2.6.1_utf8.tgz: nmail/sadmin.php <==
<?
require_once('include/global.php');
require_once('sadmin_conf.inc.php');


// set
	$CFG['TITLE'] = '<b>메일서버관리</b>';


// skin view
	nskinset('sadmin', 'sadmin.html');
	include($NSKIN['view_layout']);



// [2010-06-04] 바이러스 차단용 백신프로그램 업데이트 안내
// * 참고 : 안내가 불 필요할 경우 이 부분은 삭제하셔도 사용상 아무런 문제가 없습니다.
	flush();
	$nm_reg = nm_register_get();

	if ($nm_reg['s_virus_scan'])
	{
			$vs = get_virus_scan_version();
			$alert = '';

			if ($vs['date'] != '')
			{
				$vs['date2'] = substr($vs['date'], 0, 10);
				if ($vs['date2'] <= date('Y-m-d', time()-(86400*30)))		// 업데이트 날짜가 30일 이상 지났을 때 경고.
				{
					$alert = ' <br><br><font color=red>
					<b>- 바이러스차단 업데이트 안내</b> ( 최근 업데이트 : '.$vs['date2'].' )<br>
					&nbsp &nbsp ※ <u>바이러스차단용 백신 프로그램의 업데이트가 이루어지지 않고 있습니다.</u><br>
					&nbsp &nbsp &nbsp &nbsp 따라서 최신 바이러스를 차단할 수 없는 상황입니다.<br>
					&nbsp &nbsp &nbsp &nbsp 업데이트는 구입후 1년간 무상지원되고 있습니다.<br>
					&nbsp &nbsp &nbsp &nbsp 자세한 내용은 [<a href="'.$nmpath.'/snmail.php"><b><u>기술지원 안내</u></b></a>]를 통해 문의주시면 됩니다.</font><br>';
				}	// if()
			} else
			{
					$alert = ' <br><br><font color=red>
					<b>- 바이러스차단 업데이트 안내</b><br>
					&nbsp &nbsp ※ <u>서버에 백신프로그램이 존재하지 않거나,</u><br>
					&nbsp &nbsp &nbsp &nbsp <u>더 이상 업데이트가 지원되지 않는 제품입니다.</u><br>
					&nbsp &nbsp &nbsp &nbsp 따라서 최신 바이러스를 차단할 수 없는 상황입니다.<br>
					&nbsp &nbsp &nbsp &nbsp 업데이트는 구입후 1년간 무상지원되고 있습니다.<br>
					&nbsp &nbsp &nbsp &nbsp 자세한 내용은 [<a href="'.$nmpath.'/snmail.php"><b><u>기술지원 안내</u></b></a>]를 통해 문의주시면 됩니다.</font><br>';
			}	// if()

			if ($alert != '')
			{
				?>
					<script language="JavaScript">
					<!--
						document.getElementById('nmail_virus_alert').innerHTML = '<?= str_replace(array("\r\n", "\n"), "", $alert) ?>';
					//-->
					</script>
				<?				
			}	// if()
		?><?
	}	// if()


// [2013-07-15] 최신 버전 확인
	$url = 'http://www.passkorea.net/nmailphp/version_check.txt';
	$pu = parse_url($url);
	if ($pu['port'] == '')
		$pu['port'] = 80;

	$result = array();
	$result['code'] = 0;
	$result['msg'] = '';
	$fp = @fsockopen($pu['host'], $pu['port'], $errno, $errstr, 10);
	if (!$fp) {
		$result['msg'] = "HTTP connect fail. ".$errstr." (".$errno.")";
	} else {
	   fputs($fp, "GET ".$pu['path']."?".$pu['query']." HTTP/1.0\r\nHost: ".$pu['host']."\r\n\r\n");

	   while (!feof($fp)) {
		   $result['msg'] .= fgets ($fp,128);
	   }
	   fclose ($fp);

	   if (trim($result['msg']) != '')
	   {
		   $result['code'] = 1;
		   $ex = explode("\r\n\r\n", $result['msg']);
		   $result['msg'] = trim($ex[1]);
	   }	// if()
	}

	if (preg_match('/[0-9]+\.[0-9]+\.[0-9]+/', $result['msg']) && version_compare($result['msg'], NM_VER, '>'))		// 2.6.1.beta3 / 2.5.3.beta26.pl1 / 2.5.3.pl1 일때도 2.6.1 업데이트 확인됨. 2.6.1.pl1 는 정상적으로 미확인됨.
	{
		?>
			<script language="JavaScript">
			<!--
				document.getElementById('nmail_version_check').innerHTML = '<br><br><a href="http://www.passkorea.net/" target="_blank"><span style="color: red; font-size: 11pt; text-decoration: underline; font-weight: bold;">최신 버전( <?= $result['msg'] ?> ) 업그레이드 확인하기!!!</span></a>';
			//-->
			</script>
		<?				
	}	// if()

require_once('include/global_end.php');
?>

==> nmail-php-patch-2.6.1-to-2.6.12_utf8.tgz: nmail/sadmin.php <==
<?
require_once('include/global.php');
require_once('sadmin_conf.inc.php');


// set
	$CFG['TITLE'] = '<b>메일서버관리</b>';


// skin view
	nskinset('sadmin', 'sadmin.html');
	include($NSKIN['view_layout']);



// [2010-06-04] 바이러스 차단용 백신프로그램 업데이트 안내
// * 참고 : 안내가 불 필요할 경우 이 부분은 삭제하셔도 사용상 아무런 문제가 없습니다.
	flush();
	$nm_reg = nm_register_get();

	if ($nm_reg['s_virus_scan'])
	{
			$vs = get_virus_scan_version();
			$alert = '';

			if ($vs['date'] != '')
			{
				$vs['date2'] = substr($vs['date'], 0, 10);
				if ($vs['date2'] <= date('Y-m-d', time()-(86400*30)))		// 업데이트 날짜가 30일 이상 지났을 때 경고.
				{
					$alert = ' <br><br><font color=red>
					<b>- 바이러스차단 업데이트 안내</b> ( 최근 업데이트 : '.$vs['date2'].' )<br>
					&nbsp &nbsp ※ <u>바이러스차단용 백신 프로그램의 업데이트가 이루어지지 않고 있습니다.</u><br>
					&nbsp &nbsp &nbsp &nbsp 따라서 최신 바이러스를 차단할 수 없는 상황입니다.<br>
					&nbsp &nbsp &nbsp &nbsp 업데이트는 구입후 1년간 무상지원되고 있습니다.<br>
					&nbsp &nbsp &nbsp &nbsp 자세한 내용은 [<a href="'.$nmpath.'/snmail.php"><b><u>기술지원 안내</u></b></a>]를 통해 문의주시면 됩니다.</font><br>';
				}	// if()
			} else
			{
					$alert = ' <br><br><font color=red>
					<b>- 바이러스차단 업데이트 안내</b><br>
					&nbsp &nbsp ※ <u>서버에 백신프로그램이 존재하지 않거나,</u><br>
					&nbsp &nbsp &nbsp &nbsp <u>더 이상 업데이트가 지원되지 않는 제품입니다.</u><br>
					&nbsp &nbsp &nbsp &nbsp 따라서 최신 바이러스를 차단할 수 없는 상황입니다.<br>
					&nbsp &nbsp &nbsp &nbsp 업데이트는 구입후 1년간 무상지원되고 있습니다.<br>
					&nbsp &nbsp &nbsp &nbsp 자세한 내용은 [<a href="'.$nmpath.'/snmail.php"><b><u>기술지원 안내</u></b></a>]를 통해 문의주시면 됩니다.</font><br>';
			}	// if()

			if ($alert != '')
			{
				?>
					<script language="JavaScript">
					<!--
						document.getElementById('nmail_virus_alert').innerHTML = '<?= str_replace(array("\r\n", "\n"), "", $alert) ?>';
					//-->
					</script>
				<?				
			}	// if()
		?><?
	}	// if()


// [2013-07-15] 최신 버전 확인
	flush();
	$url = 'http://www.passkorea.net/nmailphp/version_check.txt';
	$pu = parse_url($url);
	if ($pu['port'] == '')
		$pu['port'] = 80;

	$result = array();
	$result['code'] = 0;
	$result['msg'] = '';
	$fp = @fsockopen($pu['host'], $pu['port'], $errno, $errstr, 10);
	if (!$fp) {
		$result['msg'] = "HTTP connect fail. ".$errstr." (".$errno.")";
	} else {
	   fputs($fp, "GET ".$pu['path']."?".$pu['query']." HTTP/1.0\r\nHost: ".$pu['host']."\r\n\r\n");

	   while (!feof($fp)) {
		   $result['msg'] .= fgets ($fp,128);
	   }
	   fclose ($fp);

	   if (trim($result['msg']) != '')
	   {
		   $result['code'] = 1;
		   $ex = explode("\r\n\r\n", $result['msg']);
		   $result['msg'] = trim($ex[1]);
	   }	// if()
	}

	if (preg_match('/[0-9]+\.[0-9]+\.[0-9]+/', $result['msg']) && version_compare($result['msg'], NM_VER, '>'))		// 2.6.1.beta3 / 2.5.3.beta26.pl1 / 2.5.3.pl1 일때도 2.6.1 업데이트 확인됨. 2.6.1.pl1 는 정상적으로 미확인됨.
	{
		?>
			<script language="JavaScript">
			<!--
				document.getElementById('nmail_version_check').innerHTML = '<br><br><a href="http://www.passkorea.net/" target="_blank"><span style="color: red; font-size: 11pt; text-decoration: underline; font-weight: bold;">최신 버전( <?= str_replace("'", "", $result['msg']) ?> ) 업그레이드 확인하기!!!</span></a>';
			//-->
			</script>
		<?				
	}	// if()


// [2013-08-29] SMTP 서비스 응답 확인하기
	flush();
	$fp = @fsockopen($G_SYS[SMTP_ADDR], $G_SYS[SMTP_PORT], $errno, $errstr, 10);
	if (!$fp) {
		$nmail_smtp_check = "연결 실패 - ".$errstr." (".$errno.")";
	} else {
		$nmail_smtp_check = trim(fgets($fp,1024));
		fputs($fp, "QUIT\r\n");
		fclose($fp);
	}

	preg_match('/XMail [0-9\.]+ [a-z]+([0-9]+)/i', $nmail_smtp_check, $mc);
	if (is_numeric($mc[1]) && $mc[1] >= '120228')
	{
		$nmail_smtp_check = "최신 버전으로 확인됩니다.";
	} else {
		$nmail_smtp_check = '<span style="color: red; font-size: 11pt;">메일엔진이 최신 버전이 아닙니다.  업그레이드 메뉴얼에서 [<b>메일엔진 업데이트</b>]항목을 확인하십시오.</span><br> &nbsp; &nbsp;  &nbsp; &nbsp; SMTP 응답 : '.$nmail_smtp_check;
		?>
			<script language="JavaScript">
			<!--
				document.getElementById('nmail_smtp_check').innerHTML = '<?= str_replace("'", "", $nmail_smtp_check) ?>';
			//-->
			</script>
		<?				
	}	// if()


require_once('include/global_end.php');
?>
